==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/AutoMergeOptions.java <==
package io.github.cdklabs.projen.github;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.756Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.AutoMergeOptions")
@software.amazon.jsii.Jsii.Proxy(AutoMergeOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface AutoMergeOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Number of approved code reviews.
     * <p>
     * Default: 1
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Number getApprovedReviews() {
        return null;
    }

    /**
     * (experimental) List of labels that will prevent auto-merging.
     * <p>
     * Default: ['do-not-merge']
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getBlockingLabels() {
        return null;
    }

    /**
     * (experimental) The GitHub job ID of the build workflow.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getBuildJob() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AutoMergeOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AutoMergeOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<AutoMergeOptions> {
        java.lang.Number approvedReviews;
        java.util.List<java.lang.String> blockingLabels;
        java.lang.String buildJob;

        /**
         * Sets the value of {@link AutoMergeOptions#getApprovedReviews}
         * @param approvedReviews Number of approved code reviews.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder approvedReviews(java.lang.Number approvedReviews) {
            this.approvedReviews = approvedReviews;
            return this;
        }

        /**
         * Sets the value of {@link AutoMergeOptions#getBlockingLabels}
         * @param blockingLabels List of labels that will prevent auto-merging.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder blockingLabels(java.util.List<java.lang.String> blockingLabels) {
            this.blockingLabels = blockingLabels;
            return this;
        }

        /**
         * Sets the value of {@link AutoMergeOptions#getBuildJob}
         * @param buildJob The GitHub job ID of the build workflow.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder buildJob(java.lang.String buildJob) {
            this.buildJob = buildJob;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AutoMergeOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public AutoMergeOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link AutoMergeOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AutoMergeOptions {
        private final java.lang.Number approvedReviews;
        private final java.util.List<java.lang.String> blockingLabels;
        private final java.lang.String buildJob;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.approvedReviews = software.amazon.jsii.Kernel.get(this, "approvedReviews", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.blockingLabels = software.amazon.jsii.Kernel.get(this, "blockingLabels", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.buildJob = software.amazon.jsii.Kernel.get(this, "buildJob", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.approvedReviews = builder.approvedReviews;
            this.blockingLabels = builder.blockingLabels;
            this.buildJob = builder.buildJob;
        }

        @Override
        public final java.lang.Number getApprovedReviews() {
            return this.approvedReviews;
        }

        @Override
        public final java.util.List<java.lang.String> getBlockingLabels() {
            return this.blockingLabels;
        }

        @Override
        public final java.lang.String getBuildJob() {
            return this.buildJob;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getApprovedReviews() != null) {
                data.set("approvedReviews", om.valueToTree(this.getApprovedReviews()));
            }
            if (this.getBlockingLabels() != null) {
                data.set("blockingLabels", om.valueToTree(this.getBlockingLabels()));
            }
            if (this.getBuildJob() != null) {
                data.set("buildJob", om.valueToTree(this.getBuildJob()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.AutoMergeOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AutoMergeOptions.Jsii$Proxy that = (AutoMergeOptions.Jsii$Proxy) o;

            if (this.approvedReviews != null ? !this.approvedReviews.equals(that.approvedReviews) : that.approvedReviews != null) return false;
            if (this.blockingLabels != null ? !this.blockingLabels.equals(that.blockingLabels) : that.blockingLabels != null) return false;
            return this.buildJob != null ? this.buildJob.equals(that.buildJob) : that.buildJob == null;
        }

        @Override
        public final int hashCode() {
            int result = this.approvedReviews != null ? this.approvedReviews.hashCode() : 0;
            result = 31 * result + (this.blockingLabels != null ? this.blockingLabels.hashCode() : 0);
            result = 31 * result + (this.buildJob != null ? this.buildJob.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/AutoMergeOptions.java <==
package io.github.cdklabs.projen.github;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.414Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.AutoMergeOptions")
@software.amazon.jsii.Jsii.Proxy(AutoMergeOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface AutoMergeOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Number of approved code reviews.
     * <p>
     * Default: 1
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Number getApprovedReviews() {
        return null;
    }

    /**
     * (experimental) List of labels that will prevent auto-merging.
     * <p>
     * Default: ['do-not-merge']
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getBlockingLabels() {
        return null;
    }

    /**
     * (experimental) Name of the mergify queue.
     * <p>
     * Default: 'default'
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getQueueName() {
        return null;
    }

    /**
     * (experimental) Name of the mergify rule.
     * <p>
     * Default: 'Automatic merge on approval and successful build'
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getRuleName() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AutoMergeOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AutoMergeOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<AutoMergeOptions> {
        java.lang.Number approvedReviews;
        java.util.List<java.lang.String> blockingLabels;
        java.lang.String queueName;
        java.lang.String ruleName;

        /**
         * Sets the value of {@link AutoMergeOptions#getApprovedReviews}
         * @param approvedReviews Number of approved code reviews.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder approvedReviews(java.lang.Number approvedReviews) {
            this.approvedReviews = approvedReviews;
            return this;
        }

        /**
         * Sets the value of {@link AutoMergeOptions#getBlockingLabels}
         * @param blockingLabels List of labels that will prevent auto-merging.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder blockingLabels(java.util.List<java.lang.String> blockingLabels) {
            this.blockingLabels = blockingLabels;
            return this;
        }

        /**
         * Sets the value of {@link AutoMergeOptions#getQueueName}
         * @param queueName Name of the mergify queue.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder queueName(java.lang.String queueName) {
            this.queueName = queueName;
            return this;
        }

        /**
         * Sets the value of {@link AutoMergeOptions#getRuleName}
         * @param ruleName Name of the mergify rule.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder ruleName(java.lang.String ruleName) {
            this.ruleName = ruleName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AutoMergeOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public AutoMergeOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link AutoMergeOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AutoMergeOptions {
        private final java.lang.Number approvedReviews;
        private final java.util.List<java.lang.String> blockingLabels;
        private final java.lang.String queueName;
        private final java.lang.String ruleName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.approvedReviews = software.amazon.jsii.Kernel.get(this, "approvedReviews", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.blockingLabels = software.amazon.jsii.Kernel.get(this, "blockingLabels", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.queueName = software.amazon.jsii.Kernel.get(this, "queueName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.ruleName = software.amazon.jsii.Kernel.get(this, "ruleName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.approvedReviews = builder.approvedReviews;
            this.blockingLabels = builder.blockingLabels;
            this.queueName = builder.queueName;
            this.ruleName = builder.ruleName;
        }

        @Override
        public final java.lang.Number getApprovedReviews() {
            return this.approvedReviews;
        }

        @Override
        public final java.util.List<java.lang.String> getBlockingLabels() {
            return this.blockingLabels;
        }

        @Override
        public final java.lang.String getQueueName() {
            return this.queueName;
        }

        @Override
        public final java.lang.String getRuleName() {
            return this.ruleName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getApprovedReviews() != null) {
                data.set("approvedReviews", om.valueToTree(this.getApprovedReviews()));
            }
            if (this.getBlockingLabels() != null) {
                data.set("blockingLabels", om.valueToTree(this.getBlockingLabels()));
            }
            if (this.getQueueName() != null) {
                data.set("queueName", om.valueToTree(this.getQueueName()));
            }
            if (this.getRuleName() != null) {
                data.set("ruleName", om.valueToTree(this.getRuleName()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.AutoMergeOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AutoMergeOptions.Jsii$Proxy that = (AutoMergeOptions.Jsii$Proxy) o;

            if (this.approvedReviews != null ? !this.approvedReviews.equals(that.approvedReviews) : that.approvedReviews != null) return false;
            if (this.blockingLabels != null ? !this.blockingLabels.equals(that.blockingLabels) : that.blockingLabels != null) return false;
            if (this.queueName != null ? !this.queueName.equals(that.queueName) : that.queueName != null) return false;
            return this.ruleName != null ? this.ruleName.equals(that.ruleName) : that.ruleName == null;
        }

        @Override
        public final int hashCode() {
            int result = this.approvedReviews != null ? this.approvedReviews.hashCode() : 0;
            result = 31 * result + (this.blockingLabels != null ? this.blockingLabels.hashCode() : 0);
            result = 31 * result + (this.queueName != null ? this.queueName.hashCode() : 0);
            result = 31 * result + (this.ruleName != null ? this.ruleName.hashCode() : 0);
            return result;
        }
    }
}
